imaplib.abort

Module imaplib :: Class abort |
[show private | hide private]
[frames | no frames]

## Class abort

    Exception --+
                |
            error --+
                    |
                   abort

Known Subclasses:
  `readonly`

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net